CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
78 lines
1.9 KiB
C++
78 lines
1.9 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <hip_test_defgroups.hh>
|
|
#include "printf_common.h" // NOLINT
|
|
|
|
__global__ void test_kernel_width() {
|
|
printf("%16d\n", 42);
|
|
printf("%.8d\n", 42);
|
|
printf("%16.5d\n", -42);
|
|
printf("%.8x\n", 0x42);
|
|
printf("%.8o\n", 042);
|
|
printf("%16.8e\n", 12345.67891);
|
|
printf("%16.8f\n", -12345.67891);
|
|
printf("%16.8g\n", 12345.67891);
|
|
printf("%8.4e\n", -12345.67891);
|
|
printf("%8.4f\n", 12345.67891);
|
|
printf("%8.4g\n", 12345.67891);
|
|
printf("%4.2f\n", 12345.67891);
|
|
printf("%.1f\n", 12345.67891);
|
|
printf("%.5s\n", "helloxyz");
|
|
}
|
|
/**
|
|
* @addtogroup printf printf
|
|
* @{
|
|
* @ingroup PrintfTest
|
|
* `int printf()` -
|
|
* Method to print the content on output device.
|
|
*/
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Test case to verify the floating point details via printf API
|
|
* Test source
|
|
* ------------------------
|
|
* - catch/unit/printf/hipPrintfWidthPrecision.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 6.2
|
|
*/
|
|
HIP_TEST_CASE(Unit_Printf_PrintfWidthPrecision) {
|
|
int pcieAtomic = 0;
|
|
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, 0));
|
|
if (!pcieAtomic) {
|
|
HIP_SKIP_TEST(HipTest::SkipReason::kPcieAtomicUnsupported);
|
|
}
|
|
std::string reference(R"here( 42
|
|
00000042
|
|
-00042
|
|
00000042
|
|
00000042
|
|
1.23456789e+04
|
|
-12345.67891000
|
|
12345.679
|
|
-1.2346e+04
|
|
12345.6789
|
|
1.235e+04
|
|
12345.68
|
|
12345.7
|
|
hello
|
|
)here");
|
|
CaptureStream captured(stdout);
|
|
hipLaunchKernelGGL(test_kernel_width, dim3(1), dim3(1), 0, 0);
|
|
HIP_CHECK(hipStreamSynchronize(0));
|
|
auto CapturedData = captured.getCapturedData();
|
|
std::string device_output = captured.gulp(CapturedData);
|
|
REQUIRE(device_output == reference);
|
|
}
|
|
|
|
/**
|
|
* End doxygen group PrintfTest.
|
|
* @}
|
|
*/
|